/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package gov.anl.aps.dm.api;

import gov.anl.aps.dm.common.exceptions.ConfigurationError;
import gov.anl.aps.dm.common.exceptions.DmException;
import gov.anl.aps.dm.common.exceptions.InvalidArgument;
import gov.anl.aps.dm.common.exceptions.ObjectNotFound;
import gov.anl.aps.dm.common.objects.DmObjectFactory;
import gov.anl.aps.dm.common.objects.Experiment;
import gov.anl.aps.dm.common.utilities.ArgumentUtility;
import java.util.HashMap;

/**
 *
 * @author sveseli
 */
public class ExperimentDsApi extends DmRestApi {

    /**
     * Constructor.
     *
     * @throws ConfigurationError if web service URL property is malformed or
     * null
     */
    public ExperimentDsApi() throws ConfigurationError {
        super();
    }

    /**
     * Constructor.
     *
     * @param webServiceUrl web service URL
     * @throws ConfigurationError if web service URL is malformed or null
     */
    public ExperimentDsApi(String webServiceUrl) throws ConfigurationError {
        super(webServiceUrl);
    }


    /**
     * Constructor.
     *
     * @param webServiceUrl web service URL
     * @param loginUsername login username
     * @param loginPassword login password
     * @throws ConfigurationError if web service URL is malformed or null
     */
    public ExperimentDsApi(String webServiceUrl, String loginUsername, String loginPassword) throws ConfigurationError {
        super(webServiceUrl, loginUsername, loginPassword);
    }
    
    /**
     * Update experiment (group users, etc.).
     *
     * @param experimentName experiment name
     * @return Experiment object
     * @throws InvalidArgument if provided name is empty or null
     * @throws ObjectNotFound when specified experiment does not exist
     * @throws DmException in case of all other errors
     */
    public Experiment updateExperiment(String experimentName) throws InvalidArgument, ObjectNotFound, DmException {
        ArgumentUtility.verifyNonEmptyString("Experiment name", experimentName);
        String requestUrl = "/experiments/update";
        HashMap<String, String> requestData = new HashMap<>();
        requestData.put("name", ArgumentUtility.encode(experimentName));
        String jsonString = loginAndInvokeSessionPutRequest(requestUrl, requestData);
        Experiment experiment = (Experiment) DmObjectFactory.createDmObject(jsonString, Experiment.class);
        return experiment;
    }

    /*
     * Main method, used for simple testing.
     *
     * @param args main arguments
     */
    public static void main(String[] args) {
        try {
            ExperimentDsApi client = new ExperimentDsApi("https://dmstorage.svdev.net:22236/dm", "dm", "dm");
            Experiment experiment = client.updateExperiment("e1");
            System.out.println("Updated experiment: \n" + experiment);
        } catch (DmException ex) {
            System.out.println("Sorry: " + ex);
        }
    }

}
