#!/usr/bin/env python

import os
from dm.common.cli.dmRestSessionCli import DmRestSessionCli
from dm.common.utility.osUtility import OsUtility
from dm.common.utility.configurationManager import ConfigurationManager

class DaqWebServiceSessionCli(DmRestSessionCli):
    """ DM DAQ web service session cli class. """

    DM_FILE_SERVER_URL_ENV_VAR = 'DM_FILE_SERVER_URL'
    DEFAULT_SESSION_CACHE_FILE = OsUtility.getUserHomeDir() + '/.dm/.daq.session.cache'

    def __init__(self, validArgCount=0):
        DmRestSessionCli.__init__(self, validArgCount)
        ConfigurationManager.getInstance().setSessionCacheFile(DaqWebServiceSessionCli.DEFAULT_SESSION_CACHE_FILE)

    def getDefaultServiceHost(self):
        return ConfigurationManager.getInstance().getDaqWebServiceHost()

    def getDefaultServicePort(self):
        return ConfigurationManager.getInstance().getDaqWebServicePort()

    def getId(self):
        return self.options.id

    def getExperimentName(self):
        return self.options.experimentName

    def getDataDirectory(self):
        dataDirectory = self.options.dataDirectory
        # Make sure data directory already does not have url scheme
        if dataDirectory and dataDirectory.find('://') < 0:
            fileServerUrl = os.environ.get(self.DM_FILE_SERVER_URL_ENV_VAR, '')
            dataDirectory = '%s%s' % (fileServerUrl, dataDirectory)
        return dataDirectory

